@@ -2,8 +2,10 @@
 # SPDX-License-Identifier: MIT
 
 import collections
-from typing import TYPE_CHECKING, List, Optional, SupportsIndex, overload
+import copy
+from typing import TYPE_CHECKING, Any, Dict, List, Optional, SupportsIndex, overload
 
+from specfile.formatter import formatted
 from specfile.macros import Macros
 from specfile.sections import Section
 from specfile.tags import Comments
@@ -44,9 +46,21 @@ class SourcelistEntry:
             return NotImplemented
         return self.location == other.location and self.comments == other.comments
 
+    @formatted
     def __repr__(self) -> str:
-        comments = repr(self.comments)
-        return f"SourcelistEntry('{self.location}', {comments})"
+        return (
+            f"SourcelistEntry({self.location!r}, {self.comments!r}, {self._context!r})"
+        )
+
+    def __deepcopy__(self, memo: Dict[int, Any]) -> "SourcelistEntry":
+        result = self.__class__.__new__(self.__class__)
+        memo[id(self)] = result
+        for k, v in self.__dict__.items():
+            if k == "_context":
+                continue
+            setattr(result, k, copy.deepcopy(v, memo))
+        result._context = self._context
+        return result
 
     @property
     def expanded_location(self) -> str:
@@ -84,10 +98,9 @@ class Sourcelist(collections.UserList):
             self.data = data.copy()
         self._remainder = remainder.copy() if remainder is not None else []
 
+    @formatted
     def __repr__(self) -> str:
-        data = repr(self.data)
-        remainder = repr(self._remainder)
-        return f"Sourcelist({data}, {remainder})"
+        return f"Sourcelist({self.data!r}, {self._remainder!r})"
 
     @overload
     def __getitem__(self, i: SupportsIndex) -> SourcelistEntry:
@@ -104,7 +117,7 @@ class Sourcelist(collections.UserList):
             return self.data[i]
 
     def copy(self) -> "Sourcelist":
-        return Sourcelist(self.data, self._remainder)
+        return copy.copy(self)
 
     @classmethod
     def parse(
