@@ -5,7 +5,7 @@ import copy
 
 import pytest
 
-from specfile.macro_options import MacroOptions, Token, TokenType
+from specfile.options import Options, Token, TokenType
 from specfile.prep import AutosetupMacro, PatchMacro, Prep, PrepMacros, SetupMacro
 from specfile.sections import Section
 
@@ -22,7 +22,7 @@ from specfile.sections import Section
 )
 def test_patch_macro_number(name, options, number):
     macro = PatchMacro(
-        name, MacroOptions(MacroOptions.tokenize(options), PatchMacro.OPTSTRING), " "
+        name, Options(Options.tokenize(options), PatchMacro.OPTSTRING), " "
     )
     assert macro.number == number
 
@@ -30,8 +30,8 @@ def test_patch_macro_number(name, options, number):
 def test_prep_macros_find():
     macros = PrepMacros(
         [
-            SetupMacro("%setup", MacroOptions([]), ""),
-            PatchMacro("%patch0", MacroOptions([]), ""),
+            SetupMacro("%setup", Options([]), ""),
+            PatchMacro("%patch0", Options([]), ""),
         ]
     )
     assert macros.find("%patch0") == 1
@@ -80,7 +80,7 @@ def test_prep_macros_find():
     ],
 )
 def test_prep_add_patch_macro(lines_before, number, options, lines_after):
-    prep = Prep.parse(Section("prep", lines_before))
+    prep = Prep.parse(Section("prep", data=lines_before))
     prep.add_patch_macro(number, **options)
     assert prep.get_raw_section_data() == lines_after
 
@@ -101,7 +101,7 @@ def test_prep_add_patch_macro(lines_before, number, options, lines_after):
     ],
 )
 def test_prep_remove_patch_macro(lines_before, number, lines_after):
-    prep = Prep.parse(Section("prep", lines_before))
+    prep = Prep.parse(Section("prep", data=lines_before))
     prep.remove_patch_macro(number)
     assert prep.get_raw_section_data() == lines_after
 
@@ -110,7 +110,7 @@ def test_prep_parse():
     prep = Prep.parse(
         Section(
             "prep",
-            [
+            data=[
                 "%setup -q",
                 "# a comment",
                 "%patch0 -p1",
@@ -132,7 +132,7 @@ def test_prep_get_raw_section_data():
             [
                 SetupMacro(
                     SetupMacro.CANONICAL_NAME,
-                    MacroOptions(
+                    Options(
                         [Token(TokenType.DEFAULT, "-q")],
                         SetupMacro.OPTSTRING,
                         SetupMacro.DEFAULTS,
@@ -141,7 +141,7 @@ def test_prep_get_raw_section_data():
                 ),
                 PatchMacro(
                     PatchMacro.CANONICAL_NAME + "0",
-                    MacroOptions(
+                    Options(
                         [Token(TokenType.DEFAULT, "-p1")],
                         PatchMacro.OPTSTRING,
                         PatchMacro.DEFAULTS,
@@ -151,7 +151,7 @@ def test_prep_get_raw_section_data():
                 ),
                 PatchMacro(
                     PatchMacro.CANONICAL_NAME + "2",
-                    MacroOptions(
+                    Options(
                         [Token(TokenType.DEFAULT, "-p2")],
                         PatchMacro.OPTSTRING,
                         PatchMacro.DEFAULTS,
@@ -179,7 +179,7 @@ def test_copy_prep():
             [
                 AutosetupMacro(
                     AutosetupMacro.CANONICAL_NAME,
-                    MacroOptions([]),
+                    Options([]),
                     "",
                 ),
             ],
